@@ -434,7 +434,6 @@ class Map(folium.Map):
         styles="",
         **kwargs,
     ):
-
         """Add a WMS layer to the map.
 
         Args:
@@ -515,7 +514,7 @@ class Map(folium.Map):
         attribution=".",
         opacity=1.0,
         shown=True,
-        titiler_endpoint="https://api.cogeo.xyz/",
+        titiler_endpoint="https://titiler.xyz",
         **kwargs,
     ):
         """Adds a COG TileLayer to the map.
@@ -526,10 +525,10 @@ class Map(folium.Map):
             attribution (str, optional): The attribution to use. Defaults to '.'.
             opacity (float, optional): The opacity of the layer. Defaults to 1.
             shown (bool, optional): A flag indicating whether the layer should be on by default. Defaults to True.
-            titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://api.cogeo.xyz/".
+            titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://titiler.xyz".
         """
-        tile_url = get_cog_tile(url, titiler_endpoint, **kwargs)
-        center = get_cog_center(url, titiler_endpoint)  # (lon, lat)
+        tile_url = cog_tile(url, titiler_endpoint, **kwargs)
+        center = cog_center(url, titiler_endpoint)  # (lon, lat)
         self.add_tile_layer(
             tiles=tile_url,
             name=name,
@@ -539,72 +538,10 @@ class Map(folium.Map):
         )
         self.set_center(lon=center[0], lat=center[1], zoom=10)
 
-    def add_cog_mosaic(
-        self,
-        links,
-        name="Untitled",
-        attribution=".",
-        opacity=1.0,
-        shown=True,
-        titiler_endpoint="https://api.cogeo.xyz/",
-        username="anonymous",
-        overwrite=False,
-        show_footprints=False,
-        verbose=True,
-        **kwargs,
-    ):
-        """Add a virtual mosaic of COGs to the map.
-
-        Args:
-            links (list): A list of links pointing to COGs.
-            name (str, optional): The layer name to use for the layer. Defaults to 'Untitled'.
-            attribution (str, optional): The attribution to use. Defaults to '.'.
-            opacity (float, optional): The opacity of the layer. Defaults to 1.
-            shown (bool, optional): A flag indicating whether the layer should be on by default. Defaults to True.
-            titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://api.cogeo.xyz/".
-            username (str, optional): The username to create mosaic using the titiler endpoint. Defaults to 'anonymous'.
-            overwrite (bool, optional): Whether or not to replace existing layer with the same layer name. Defaults to False.
-            show_footprints (bool, optional): Whether or not to show footprints of COGs. Defaults to False.
-            verbose (bool, optional): Whether or not to print descriptions. Defaults to True.
-        """
-        layername = name.replace(" ", "_")
-        tile = get_cog_mosaic(
-            links,
-            titiler_endpoint=titiler_endpoint,
-            username=username,
-            layername=layername,
-            overwrite=overwrite,
-            verbose=verbose,
+    def add_cog_mosaic(self, **kwargs):
+        raise NotImplementedError(
+            "This function is no longer supported.See https://github.com/giswqs/leafmap/issues/180."
         )
-        self.add_tile_layer(tile, name, attribution, opacity, shown)
-
-        if show_footprints:
-            if verbose:
-                print(
-                    f"Generating footprints of {len(links)} COGs. This might take a while ..."
-                )
-            coords = []
-            for link in links:
-                coord = get_cog_bounds(link)
-                if coord is not None:
-                    coords.append(coord)
-            fc = coords_to_geojson(coords)
-
-            # style_function = lambda x: {'opacity': 1, 'dashArray': '1', 'fillOpacity': 0, 'weight': 1}
-
-            folium.GeoJson(
-                data=fc,
-                # style_function=style_function,
-                name="Footprints",
-            ).add_to(self)
-
-            center = get_center(fc)
-            if verbose:
-                print("The footprint layer has been added.")
-        else:
-            center = get_cog_center(links[0], titiler_endpoint)
-
-        self.set_center(center[0], center[1], zoom=6)
 
     def add_stac_layer(
         self,
@@ -614,7 +551,7 @@ class Map(folium.Map):
         attribution=".",
         opacity=1.0,
         shown=True,
-        titiler_endpoint="https://api.cogeo.xyz/",
+        titiler_endpoint="https://titiler.xyz",
         **kwargs,
     ):
         """Adds a STAC TileLayer to the map.
@@ -625,10 +562,10 @@ class Map(folium.Map):
             attribution (str, optional): The attribution to use. Defaults to '.'.
             opacity (float, optional): The opacity of the layer. Defaults to 1.
             shown (bool, optional): A flag indicating whether the layer should be on by default. Defaults to True.
-            titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://api.cogeo.xyz/".
+            titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://titiler.xyz".
         """
-        tile_url = get_stac_tile(url, bands, titiler_endpoint, **kwargs)
-        center = get_stac_center(url, titiler_endpoint)
+        tile_url = stac_tile(url, bands, titiler_endpoint, **kwargs)
+        center = stac_center(url, titiler_endpoint)
         self.add_tile_layer(
             tiles=tile_url,
             name=name,
