@@ -4,156 +4,17 @@ import os
 
 import ee
 import folium
+from box import Box
 from folium import plugins
 
+from .basemaps import xyz_to_folium
 from .common import *
 from .conversion import *
 from .legends import builtin_legends
 from .osm import *
 from .timelapse import *
 
-
-# More WMS basemaps can be found at https://viewer.nationalmap.gov/services/
-ee_basemaps = {
-    "ROADMAP": folium.TileLayer(
-        tiles="https://mt1.google.com/vt/lyrs=m&x={x}&y={y}&z={z}",
-        attr="Google",
-        name="Google Maps",
-        overlay=True,
-        control=True,
-        max_zoom=24,
-    ),
-    "SATELLITE": folium.TileLayer(
-        tiles="https://mt1.google.com/vt/lyrs=s&x={x}&y={y}&z={z}",
-        attr="Google",
-        name="Google Satellite",
-        overlay=True,
-        control=True,
-        max_zoom=24,
-    ),
-    "TERRAIN": folium.TileLayer(
-        tiles="https://mt1.google.com/vt/lyrs=p&x={x}&y={y}&z={z}",
-        attr="Google",
-        name="Google Terrain",
-        overlay=True,
-        control=True,
-        max_zoom=24,
-    ),
-    "HYBRID": folium.TileLayer(
-        tiles="https://mt1.google.com/vt/lyrs=y&x={x}&y={y}&z={z}",
-        attr="Google",
-        name="Google Satellite",
-        overlay=True,
-        control=True,
-        max_zoom=24,
-    ),
-    "ESRI": folium.TileLayer(
-        tiles="https://server.arcgisonline.com/ArcGIS/rest/services/World_Imagery/MapServer/tile/{z}/{y}/{x}",
-        attr="Esri",
-        name="Esri Satellite",
-        overlay=True,
-        control=True,
-        max_zoom=24,
-    ),
-    "Esri Ocean": folium.TileLayer(
-        tiles="https://services.arcgisonline.com/ArcGIS/rest/services/Ocean/World_Ocean_Base/MapServer/tile/{z}/{y}/{x}",
-        attr="Esri",
-        name="Esri Ocean",
-        overlay=True,
-        control=True,
-        max_zoom=24,
-    ),
-    "Esri Satellite": folium.TileLayer(
-        tiles="https://server.arcgisonline.com/ArcGIS/rest/services/World_Imagery/MapServer/tile/{z}/{y}/{x}",
-        attr="Esri",
-        name="Esri Satellite",
-        overlay=True,
-        control=True,
-        max_zoom=24,
-    ),
-    "Esri Standard": folium.TileLayer(
-        tiles="https://server.arcgisonline.com/ArcGIS/rest/services/World_Street_Map/MapServer/tile/{z}/{y}/{x}",
-        attr="Esri",
-        name="Esri Standard",
-        overlay=True,
-        control=True,
-        max_zoom=24,
-    ),
-    "Esri Terrain": folium.TileLayer(
-        tiles="https://server.arcgisonline.com/ArcGIS/rest/services/World_Terrain_Base/MapServer/tile/{z}/{y}/{x}",
-        attr="Esri",
-        name="Esri Terrain",
-        overlay=True,
-        control=True,
-        max_zoom=24,
-    ),
-    "Esri Transportation": folium.TileLayer(
-        tiles="https://server.arcgisonline.com/ArcGIS/rest/services/Reference/World_Transportation/MapServer/tile/{z}/{y}/{x}",
-        attr="Esri",
-        name="Esri Transportation",
-        overlay=True,
-        control=True,
-        max_zoom=24,
-    ),
-    "Esri Topo World": folium.TileLayer(
-        tiles="https://services.arcgisonline.com/ArcGIS/rest/services/World_Topo_Map/MapServer/tile/{z}/{y}/{x}",
-        attr="Esri",
-        name="Esri Topo World",
-        overlay=True,
-        control=True,
-        max_zoom=24,
-    ),
-    "Esri National Geographic": folium.TileLayer(
-        tiles="http://services.arcgisonline.com/ArcGIS/rest/services/NatGeo_World_Map/MapServer/tile/{z}/{y}/{x}",
-        attr="Esri",
-        name="Esri National Geographic",
-        overlay=True,
-        control=True,
-        max_zoom=24,
-    ),
-    "Esri Shaded Relief": folium.TileLayer(
-        tiles="https://services.arcgisonline.com/arcgis/rest/services/World_Shaded_Relief/MapServer/tile/{z}/{y}/{x}",
-        attr="Esri",
-        name="Esri Shaded Relief",
-        overlay=True,
-        control=True,
-        max_zoom=24,
-    ),
-    "Esri Physical Map": folium.TileLayer(
-        tiles="https://services.arcgisonline.com/arcgis/rest/services/World_Physical_Map/MapServer/tile/{z}/{y}/{x}",
-        attr="Esri",
-        name="Esri Physical Map",
-        overlay=True,
-        control=True,
-        max_zoom=24,
-    ),
-    "Bing VirtualEarth": folium.TileLayer(
-        tiles="http://ecn.t3.tiles.virtualearth.net/tiles/a{q}.jpeg?g=1",
-        attr="Microsoft",
-        name="Bing VirtualEarth",
-        overlay=True,
-        control=True,
-        max_zoom=24,
-    ),
-    "3DEP Elevation": folium.WmsTileLayer(
-        url="https://elevation.nationalmap.gov/arcgis/services/3DEPElevation/ImageServer/WMSServer?",
-        layers="3DEPElevation:None",
-        attr="USGS",
-        name="3DEP Elevation",
-        overlay=True,
-        control=True,
-        max_zoom=24,
-    ),
-    "NAIP Imagery": folium.WmsTileLayer(
-        url="https://services.nationalmap.gov/arcgis/services/USGSNAIPImagery/ImageServer/WMSServer?",
-        layers="0",
-        attr="USGS",
-        name="NAIP Imagery",
-        overlay=True,
-        control=True,
-        max_zoom=24,
-    ),
-}
+folium_basemaps = Box(xyz_to_folium(), frozen_box=True)
 
 
 class Map(folium.Map):
@@ -219,9 +80,9 @@ class Map(folium.Map):
         self.baseclass = "folium"
 
         if kwargs.get("add_google_map"):
-            ee_basemaps["ROADMAP"].add_to(self)
+            folium_basemaps["ROADMAP"].add_to(self)
         if kwargs.get("basemap"):
-            ee_basemaps[kwargs.get("basemap")].add_to(self)
+            folium_basemaps[kwargs.get("basemap")].add_to(self)
         if kwargs.get("plugin_LatLngPopup"):
             folium.LatLngPopup().add_to(self)
         if kwargs.get("plugin_Fullscreen"):
@@ -246,11 +107,11 @@ class Map(folium.Map):
             types ([type], optional): A list of mapTypeIds to make available. If omitted, but opt_styles is specified, appends all of the style keys to the standard Google Maps API map types.. Defaults to None.
         """
         try:
-            ee_basemaps[mapTypeId].add_to(self)
+            folium_basemaps[mapTypeId].add_to(self)
         except Exception:
             raise Exception(
                 "Basemap can only be one of the following: {}".format(
-                    ", ".join(ee_basemaps.keys())
+                    ", ".join(folium_basemaps.keys())
                 )
             )
 
@@ -263,11 +124,11 @@ class Map(folium.Map):
             basemap (str, optional): Can be one of string from ee_basemaps. Defaults to 'HYBRID'.
         """
         try:
-            ee_basemaps[basemap].add_to(self)
+            folium_basemaps[basemap].add_to(self)
         except Exception:
             raise Exception(
                 "Basemap can only be one of the following: {}".format(
-                    ", ".join(ee_basemaps.keys())
+                    ", ".join(folium_basemaps.keys())
                 )
             )
 
@@ -515,7 +376,6 @@ class Map(folium.Map):
         styles="",
         **kwargs,
     ):
-
         """Add a WMS layer to the map.
 
         Args:
@@ -596,7 +456,8 @@ class Map(folium.Map):
         attribution=".",
         opacity=1.0,
         shown=True,
-        titiler_endpoint="https://api.cogeo.xyz/",
+        bands=None,
+        titiler_endpoint="https://titiler.xyz",
         **kwargs,
     ):
         """Adds a COG TileLayer to the map.
@@ -607,10 +468,11 @@ class Map(folium.Map):
             attribution (str, optional): The attribution to use. Defaults to '.'.
             opacity (float, optional): The opacity of the layer. Defaults to 1.
             shown (bool, optional): A flag indicating whether the layer should be on by default. Defaults to True.
-            titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://api.cogeo.xyz/".
+            bands (list, optional): A list of bands to use. Defaults to None.
+            titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://titiler.xyz".
         """
-        tile_url = get_cog_tile(url, titiler_endpoint, **kwargs)
-        center = get_cog_center(url, titiler_endpoint)  # (lon, lat)
+        tile_url = cog_tile(url, bands, titiler_endpoint, **kwargs)
+        bounds = cog_bounds(url, titiler_endpoint)
         self.add_tile_layer(
             tiles=tile_url,
             name=name,
@@ -618,106 +480,53 @@ class Map(folium.Map):
             opacity=opacity,
             shown=shown,
         )
-        self.set_center(lon=center[0], lat=center[1], zoom=10)
+        self.fit_bounds([[bounds[1], bounds[0]], [bounds[3], bounds[2]]])
 
-    def add_cog_mosaic(
-        self,
-        links,
-        name="Untitled",
-        attribution=".",
-        opacity=1.0,
-        shown=True,
-        titiler_endpoint="https://api.cogeo.xyz/",
-        username="anonymous",
-        overwrite=False,
-        show_footprints=False,
-        verbose=True,
-        **kwargs,
-    ):
-        """Add a virtual mosaic of COGs to the map.
-
-        Args:
-            links (list): A list of links pointing to COGs.
-            name (str, optional): The layer name to use for the layer. Defaults to 'Untitled'.
-            attribution (str, optional): The attribution to use. Defaults to '.'.
-            opacity (float, optional): The opacity of the layer. Defaults to 1.
-            shown (bool, optional): A flag indicating whether the layer should be on by default. Defaults to True.
-            titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://api.cogeo.xyz/".
-            username (str, optional): The username to create mosaic using the titiler endpoint. Defaults to 'anonymous'.
-            overwrite (bool, optional): Whether or not to replace existing layer with the same layer name. Defaults to False.
-            show_footprints (bool, optional): Whether or not to show footprints of COGs. Defaults to False.
-            verbose (bool, optional): Whether or not to print descriptions. Defaults to True.
-        """
-        layername = name.replace(" ", "_")
-        tile = get_cog_mosaic(
-            links,
-            titiler_endpoint=titiler_endpoint,
-            username=username,
-            layername=layername,
-            overwrite=overwrite,
-            verbose=verbose,
+    def add_cog_mosaic(self, **kwargs):
+        raise NotImplementedError(
+            "This function is no longer supported.See https://github.com/giswqs/leafmap/issues/180."
         )
-        self.add_tile_layer(tile, name, attribution, opacity, shown)
-
-        if show_footprints:
-            if verbose:
-                print(
-                    f"Generating footprints of {len(links)} COGs. This might take a while ..."
-                )
-            coords = []
-            for link in links:
-                coord = get_cog_bounds(link)
-                if coord is not None:
-                    coords.append(coord)
-            fc = coords_to_geojson(coords)
-
-            # style_function = lambda x: {'opacity': 1, 'dashArray': '1', 'fillOpacity': 0, 'weight': 1}
-
-            folium.GeoJson(
-                data=fc,
-                # style_function=style_function,
-                name="Footprints",
-            ).add_to(self)
-
-            center = get_center(fc)
-            if verbose:
-                print("The footprint layer has been added.")
-        else:
-            center = get_cog_center(links[0], titiler_endpoint)
-
-        self.set_center(center[0], center[1], zoom=6)
 
     def add_stac_layer(
         self,
-        url,
+        url=None,
+        collection=None,
+        items=None,
+        assets=None,
         bands=None,
-        name="Untitled",
+        titiler_endpoint=None,
+        name="STAC Layer",
         attribution=".",
         opacity=1.0,
         shown=True,
-        titiler_endpoint="https://api.cogeo.xyz/",
         **kwargs,
     ):
         """Adds a STAC TileLayer to the map.
 
         Args:
-            url (str): The URL of the COG tile layer.
-            name (str, optional): The layer name to use for the layer. Defaults to 'Untitled'.
-            attribution (str, optional): The attribution to use. Defaults to '.'.
+            url (str): HTTP URL to a STAC item, e.g., https://canada-spot-ortho.s3.amazonaws.com/canada_spot_orthoimages/canada_spot5_orthoimages/S5_2007/S5_11055_6057_20070622/S5_11055_6057_20070622.json
+            collection (str): The Microsoft Planetary Computer STAC collection ID, e.g., landsat-8-c2-l2.
+            items (str): The Microsoft Planetary Computer STAC item ID, e.g., LC08_L2SP_047027_20201204_02_T1.
+            assets (str | list): The Microsoft Planetary Computer STAC asset ID, e.g., ["SR_B7", "SR_B5", "SR_B4"].
+            bands (list): A list of band names, e.g., ["SR_B7", "SR_B5", "SR_B4"]
+            titiler_endpoint (str, optional): Titiler endpoint, e.g., "https://titiler.xyz", "planetary-computer", "pc". Defaults to None.
+            name (str, optional): The layer name to use for the layer. Defaults to 'STAC Layer'.
+            attribution (str, optional): The attribution to use. Defaults to ''.
             opacity (float, optional): The opacity of the layer. Defaults to 1.
             shown (bool, optional): A flag indicating whether the layer should be on by default. Defaults to True.
-            titiler_endpoint (str, optional): Titiler endpoint. Defaults to "https://api.cogeo.xyz/".
         """
-        tile_url = get_stac_tile(url, bands, titiler_endpoint, **kwargs)
-        center = get_stac_center(url, titiler_endpoint)
+        tile_url = stac_tile(
+            url, collection, items, assets, bands, titiler_endpoint, **kwargs
+        )
+        bounds = stac_bounds(url, collection, items, titiler_endpoint)
         self.add_tile_layer(
-            tiles=tile_url,
+            url=tile_url,
             name=name,
             attribution=attribution,
             opacity=opacity,
             shown=shown,
         )
-        self.set_center(lon=center[0], lat=center[1], zoom=10)
+        self.fit_bounds([[bounds[1], bounds[0]], [bounds[3], bounds[2]]])
 
     def add_local_tile(
         self,
@@ -1902,6 +1711,8 @@ class Map(folium.Map):
         font_weight="normal",
         x="longitude",
         y="latitude",
+        draggable=True,
+        layer_name="Labels",
         **kwargs,
     ):
         """Adds a label layer to the map. Reference: https://python-visualization.github.io/folium/modules.html#folium.features.DivIcon
@@ -1915,16 +1726,35 @@ class Map(folium.Map):
             font_weight (str, optional): The font weight of the labels, can be normal, bold. Defaults to "normal".
             x (str, optional): The column name of the longitude. Defaults to "longitude".
             y (str, optional): The column name of the latitude. Defaults to "latitude".
+            draggable (bool, optional): Whether the labels are draggable. Defaults to True.
+            layer_name (str, optional): The name of the layer. Defaults to "Labels".
 
         """
+        import warnings
         import pandas as pd
         from folium.features import DivIcon
 
+        warnings.filterwarnings("ignore")
+
         if isinstance(data, ee.FeatureCollection):
             centroids = vector_centroids(data)
             df = ee_to_df(centroids)
         elif isinstance(data, pd.DataFrame):
             df = data
+        elif isinstance(data, str):
+            ext = os.path.splitext(data)[1]
+            if ext == ".csv":
+                df = pd.read_csv(data)
+            elif ext in [".geojson", ".json", ".shp", ".gpkg"]:
+                try:
+                    import geopandas as gpd
+
+                    df = gpd.read_file(data)
+                    df[x] = df.centroid.x
+                    df[y] = df.centroid.y
+                except:
+                    print("geopandas is required to read geojson.")
+                    return
         else:
             raise ValueError("data must be a DataFrame or an ee.FeatureCollection.")
 
@@ -1940,6 +1770,7 @@ class Map(folium.Map):
         except:
             raise ValueError("font_size must be something like '10pt'")
 
+        layer_group = folium.FeatureGroup(name=layer_name)
         for index in df.index:
             html = f'<div style="font-size: {font_size};color:{font_color};font-family:{font_family};font-weight: {font_weight}">{df[column][index]}</div>'
             folium.Marker(
@@ -1950,7 +1781,14 @@ class Map(folium.Map):
                     html=html,
                     **kwargs,
                 ),
-            ).add_to(self)
+                draggable=draggable,
+            ).add_to(layer_group)
+
+        layer_group.add_to(self)
+
+    def remove_labels(self, **kwargs):
+        """Removes a layer from the map."""
+        print("The folium plotting backend does not support removing labels.")
 
 
 def delete_dp_report(name):
